==> dde-control-center_5.3.99.1.orig.tar.xz: dde-control-center-5.3.99.1/src/frame/window/modules/notification/notificationwidget.h <==
/*
 * Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
 *
 * Author:     guoyao <guoyao@uniontech.com>
 *
 * Maintainer: guoyao <guoyao@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include "modules/notification/notificationmodel.h"
#include "interface/namespace.h"

#include <dtkwidget_global.h>

#include <QWidget>
#include <QModelIndex>

DWIDGET_BEGIN_NAMESPACE
class DListView;
DWIDGET_END_NAMESPACE

QT_BEGIN_NAMESPACE
class QStandardItemModel;
class QVBoxLayout;
QT_END_NAMESPACE

namespace DCC_NAMESPACE {
namespace notification {

class NotificationWidget : public QWidget
{
    Q_OBJECT
public:
    explicit NotificationWidget(dcc::notification::NotificationModel *model, QWidget *parent = nullptr);
    QIcon getAppIcon(const QString &appIcon, const QSize &size);

Q_SIGNALS:
    void requestShowSystem();
    void requestShowApp(int);

public Q_SLOTS:
    void onAppClicked(const QModelIndex &index);
    void setAppCurrentIndex(int row);
    void onSystemClicked(const QModelIndex &index);
    void refreshList();
    Dtk::Widget::DListView* getAppListview() const {return m_softwareListView;}
    Dtk::Widget::DListView* getSysListview() const {return m_systemListView;}

private:
    const QPixmap loadSvg(const QString &fileName, const QSize &size);

private:
    Dtk::Widget::DListView *m_softwareListView;
    Dtk::Widget::DListView *m_systemListView;
    QStandardItemModel *m_sysmodel;
    QStandardItemModel *m_softwaremodel;
    QVBoxLayout *m_centralLayout;
    dcc::notification::NotificationModel *m_model;
    QString m_theme;
    QModelIndex m_lastIndex;
};

}
}

==> dde-control-center_5.5.197.orig.tar.xz: dde-control-center-5.5.197/src/frame/window/modules/notification/notificationwidget.h <==
// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#pragma once

#include "modules/notification/notificationmodel.h"
#include "interface/namespace.h"

#include <dtkwidget_global.h>

#include <QWidget>
#include <QModelIndex>

DWIDGET_BEGIN_NAMESPACE
class DListView;
DWIDGET_END_NAMESPACE

QT_BEGIN_NAMESPACE
class QStandardItemModel;
class QVBoxLayout;
class QGSettings;
class QLabel;
QT_END_NAMESPACE

namespace dcc {
namespace widgets {
class MultiSelectListView;
}
}

namespace DCC_NAMESPACE {
namespace notification {

class NotificationWidget : public QWidget
{
    Q_OBJECT
public:
    explicit NotificationWidget(dcc::notification::NotificationModel *model, QWidget *parent = nullptr);
    ~NotificationWidget() override;
    QIcon getAppIcon(const QString &appIcon, const QSize &size);

Q_SIGNALS:
    void requestShowSystem();
    void requestShowApp(int);
    void popWidget();

public Q_SLOTS:
    void onAppClicked(const QModelIndex &index);
    void setAppCurrentIndex(int row);
    void onSystemClicked(const QModelIndex &index);
    void refreshList();
    Dtk::Widget::DListView* getAppListview() const {return (Dtk::Widget::DListView*)m_softwareListView;}
    Dtk::Widget::DListView* getSysListview() const {return m_systemListView;}
    void showDefaultWidget();
    void onSettingChanged(const QString &key);

private:
    const QPixmap loadSvg(const QString &fileName, const QSize &size);

private:
    dcc::widgets::MultiSelectListView *m_softwareListView;
    Dtk::Widget::DListView *m_systemListView;
    QStandardItemModel *m_sysmodel;
    QStandardItemModel *m_softwaremodel;
    QVBoxLayout *m_centralLayout;
    dcc::notification::NotificationModel *m_model;
    QString m_theme;
    QModelIndex m_lastIndex;
    QGSettings *m_setting;
    QLabel *m_appTitleLable;
};

}
}
